# Contributing

Thank you for showing interest in improving JSONTas, it is appreciated!

## Proposing changes

Anyone can propose changes by just writing an issue in GitHub. These proposals will be reviewed by our maintainers in order to make sure that it's feasable.

When writing proposals for JSONTas, be as precise as possible and include arguments as to why this change is beneficial and possible downsides.

Note that our maintainers will implement submitted proposals in due time and that you are welcome to implement the proposal yourself for faster integration. During implementation, it is required to assign yourself to the issue and following the contribution guide below.

## How to contribute

Make contributions by forking the project, make the change and create a pull request. Note that it is required to link an issue in the pull request unless it is a very minor change (i.e. spelling corrections etc.).

Every pull request is appreciated but note that all changes might not be accepted. If this is the case, the reasons shall be communicated in the pull request. If there is no communication or the communicated reasons are not clear enough, do not hesitate to contact the maintainers at jsontas-maintainers@google-groups.com

### License

All contributions must be licensed under the Apache License 2.0. This means that a license notice shall be included in every file in the following format:

> Copyright <Year(s)> <Copyright holder of original contribution [and others].>

> For a full list of idividual contributors, please see the commit history.
